*********
Changelog
*********

This project follows the guidelines of `Keep a changelog`_ and adheres to
`Semantic versioning`_.

.. _Keep a changelog: http://keepachangelog.com/
.. _Semantic versioning: https://semver.org/


`0.1.0`_ - 2023-08-01
=====================

Added
-----
* Files from keysightosc library.
* Some functions described in the tektronix visa command guide.

Changed
-------
* Updated all keysightosc functions to work with tektronix devices.

.. _0.1.0: https://github.com/bmecke/tektronixosc/releases/tag/0.1.0
